@@ -163,6 +163,7 @@ void EntrezFetcher::stop() {
 }
 
 void EntrezFetcher::slotComplete(KJob*) {
+  Q_ASSERT(m_job);
   if(m_job->error()) {
     m_job->ui()->showErrorMessage();
     stop();
@@ -175,6 +176,9 @@ void EntrezFetcher::slotComplete(KJob*) {
     stop();
     return;
   }
+  // see bug 319662. If fetcher is cancelled, job is killed
+  // if the pointer is retained, it gets double-deleted
+  m_job = 0;
 
 #if 0
   myWarning() << "Remove debug from entrezfetcher.cpp: " << __LINE__;
