@@ -33,6 +33,7 @@
 #include "../collectionfactory.h"
 #include "../entry.h"
 #include "../images/imagefactory.h"
+#include "../images/image.h"
 
 #include <KStandardDirs>
 
@@ -73,6 +74,12 @@ void DiscogsFetcherTest::testTitle() {
   QVERIFY(!entry->field(QLatin1String("label")).isEmpty());
   QVERIFY(!entry->field(QLatin1String("year")).isEmpty());
   QVERIFY(!entry->field(QLatin1String("track")).isEmpty());
+  // OAuth is now required
+  /*
+  QVERIFY(!entry->field(QLatin1String("cover")).isEmpty());
+  const Tellico::Data::Image& img = Tellico::ImageFactory::imageById(entry->field(QLatin1String("cover")));
+  QVERIFY(!img.isNull());
+  */
 }
 
 void DiscogsFetcherTest::testPerson() {
@@ -89,6 +96,12 @@ void DiscogsFetcherTest::testPerson() {
   QVERIFY(!entry->field(QLatin1String("title")).isEmpty());
   QVERIFY(!entry->field(QLatin1String("label")).isEmpty());
   QVERIFY(!entry->field(QLatin1String("track")).isEmpty());
+  //OAuth is now required
+  /*
+  QVERIFY(!entry->field(QLatin1String("cover")).isEmpty());
+  const Tellico::Data::Image& img = Tellico::ImageFactory::imageById(entry->field(QLatin1String("cover")));
+  QVERIFY(!img.isNull());
+  */
 }
 
 void DiscogsFetcherTest::testKeyword() {
@@ -106,4 +119,10 @@ void DiscogsFetcherTest::testKeyword() {
   QVERIFY(!entry->field(QLatin1String("label")).isEmpty());
   QVERIFY(!entry->field(QLatin1String("year")).isEmpty());
   QVERIFY(!entry->field(QLatin1String("track")).isEmpty());
+  // OAuth is now required
+  /*
+  QVERIFY(!entry->field(QLatin1String("cover")).isEmpty());
+  const Tellico::Data::Image& img = Tellico::ImageFactory::imageById(entry->field(QLatin1String("cover")));
+  QVERIFY(!img.isNull());
+  */
 }
